function retval = GMAVariableFreeVol(fcn, varargin)
% Coordination number variable for GMA

if nargin < 1
    error('GMA:internal:GMAVariableFreeVol:nargin1', 'There must be at least one argument.')
end

switch fcn
    case 'getVariableName'
        retval = 'Free Volume';
    case 'getVersion'
        retval = 1.0;
    case 'getHooks'
        retval = {'variables'};
    case 'getDependencies'
        retval = {'GMAVariableVoronoi'};
    case 'getDescription'
        retval = 'The free volume is [(Voronoi volume - HCP Voronoi Volume) / HCP Voronoi Volume].';
    case 'getProperties'
        retval = struct('average', true, 'trackParticle', true, 'singleValue', false, 'neighborList', false);
    case 'calculate'
        if nargin < 2; error('GMA:internal:GMAVariableFreeVol:nargin3', 'There must be three arguments.'); end
        GMAVariableFreeVol_calculate(varargin{1}, varargin{2})
    otherwise
        error('GMA:internal:GMAVariableFreeVol:unrecognizedFcn', 'The function was unrecognized.')
end

    function GMAVariableFreeVol_calculate(dataObj, wh)
        waitbar(0, wh, 'Calculating Free Volume')
        for n = 1:length(dataObj.timesteps)
            if ~(dataObj.timesteps{n}.radius > 0)
                if ~(dataObj.defaultRadius > 0)
                    error('GMA:info:GMAVariableFreeVol:needRadius', 'radius')
                end
                dataObj.timesteps{n}.setRadius(dataObj.defaultRadius)
            end
        end
        waitLength = length(dataObj.timesteps);
        for n = 1:length(dataObj.timesteps)
            waitbar((n-0.5)/waitLength, wh, ['Timestep ' num2str(n) '.'])
            HCPVol = 4 / sqrt(2) * (dataObj.timesteps{n}.radius ^ 3);
            vVol = dataObj.timesteps{n}.getVariable('Voronoi Volume');
            freeVol = (vVol - HCPVol) ./ HCPVol;
            % Save the variables to the timestep
            dataObj.timesteps{n}.setVariable('Free Volume', freeVol)
        end
        dataObj.variablesSet{end+1} = 'Free Volume';
    end % function GMAVariableFreeVol_calculate
end % function GMAVariableFreeVol


