function retval = GMAVariableSolidsFraction(fcn, varargin)
% Coordination number variable for GMA

if nargin < 1
    error('GMA:internal:GMAVariableSolidsFraction:nargin1', 'There must be at least one argument.')
end

switch fcn
    case 'getVariableName'
        retval = 'Solids Fraction';
    case 'getVersion'
        retval = 1.0;
    case 'getHooks'
        retval = {'variables'};
    case 'getDependencies'
        retval = {'GMAVariableVoronoi'};
    case 'getDescription'
        retval = 'The solids fraction is [Sphere Volume / Voronoi Volume].';
    case 'getProperties'
        retval = struct('average', true, 'trackParticle', true, 'singleValue', false, 'neighborList', false);
    case 'calculate'
        if nargin < 2; error('GMA:internal:GMAVariableSolidsFraction:nargin3', 'There must be three arguments.'); end
        GMAVariableSolidsFraction_calculate(varargin{1}, varargin{2})
    otherwise
        error('GMA:internal:GMAVariableSolidsFraction:unrecognizedFcn', 'The function was unrecognized.')
end

    function GMAVariableSolidsFraction_calculate(dataObj, wh)
        waitbar(0, wh, 'Calculating Free Volume')
        for n = 1:length(dataObj.timesteps)
            if ~(dataObj.timesteps{n}.radius > 0)
                if ~(dataObj.defaultRadius > 0)
                    error('GMA:info:GMAVariableSolidsFraction:needRadius', 'radius')
                end
                dataObj.timesteps{n}.setRadius(dataObj.defaultRadius)
            end
        end
        waitLength = length(dataObj.timesteps);
        for n = 1:length(dataObj.timesteps)
            waitbar((n-0.5)/waitLength, wh, ['Solids Fraction: Timestep ' num2str(n) '.'])
            sphereVol = 4 / 3 * pi * (dataObj.timesteps{n}.radius ^ 3);
            vVol = dataObj.timesteps{n}.getVariable('Voronoi Volume');
            solidsFrac = sphereVol ./ vVol;
            save('testsolids.txt', 'solidsFrac', '-ascii')
            % Save the variables to the timestep
            dataObj.timesteps{n}.setVariable('Solids Fraction', solidsFrac)
        end
        dataObj.variablesSet{end+1} = 'Solids Fraction';
    end % function GMAVariableSolidsFraction_calculate
end % function GMAVariableSolidsFraction


