function retval = GMAVariableVoidsFraction(fcn, varargin)
% Coordination number variable for GMA

if nargin < 1
    error('GMA:internal:GMAVariableVoidsFraction:nargin1', 'There must be at least one argument.')
end

switch fcn
    case 'getVariableName'
        retval = 'Voids Fraction';
    case 'getVersion'
        retval = 1.0;
    case 'getHooks'
        retval = {'variables'};
    case 'getDependencies'
        retval = {'GMAVariableVoronoi'};
    case 'getDescription'
        retval = 'The voids fraction is [(Voronoi Volume - Sphere Volume) / Voronoi Volume].';
    case 'getProperties'
        retval = struct('average', true, 'trackParticle', true, 'singleValue', false, 'neighborList', false);
    case 'calculate'
        if nargin < 2; error('GMA:internal:GMAVariableVoidsFraction:nargin3', 'There must be three arguments.'); end
        GMAVariableVoidsFraction_calculate(varargin{1}, varargin{2})
    otherwise
        error('GMA:internal:GMAVariableVoidsFraction:unrecognizedFcn', 'The function was unrecognized.')
end

    function GMAVariableVoidsFraction_calculate(dataObj, wh)
        waitbar(0, wh, 'Calculating Free Volume')
        for n = 1:length(dataObj.timesteps)
            if ~(dataObj.timesteps{n}.radius > 0)
                if ~(dataObj.defaultRadius > 0)
                    error('GMA:info:GMAVariableVoidsFraction:needRadius', 'radius')
                end
                dataObj.timesteps{n}.setRadius(dataObj.defaultRadius)
            end
        end
        waitLength = length(dataObj.timesteps);
        for n = 1:length(dataObj.timesteps)
            waitbar((n-0.5)/waitLength, wh, ['Timestep ' num2str(n) '.'])
            sphereVol = 4 / 3 * pi * (dataObj.timesteps{n}.radius ^ 3);
            vVol = dataObj.timesteps{n}.getVariable('Voronoi Volume');
            voidsFrac = sphereVol ./ vVol;
            % Save the variables to the timestep
            dataObj.timesteps{n}.setVariable('Voids Fraction', voidsFrac)
        end
        dataObj.variablesSet{end+1} = 'Voids Fraction';
    end % function GMAVariableVoidsFraction_calculate
end % function GMAVariableVoidsFraction


