function retval = GMAVisualizationHistogram(fcn, varargin)

if nargin < 1
    error('GMA:internal:GMAVisualizationHistogram:nargin1', 'There must be at least one argument.')
end

switch fcn
    case 'getVisualizationName'
        retval = 'Histogram';
    case 'getVersion'
        retval = 1.0;
    case 'getHooks'
        retval = {'visualizations'};
    case 'getDependencies'
        retval = {};
    case 'getDescription'
        if nargin < 3
            error('GMA:internal:GMAVisualizationHistogram:nargin2', 'There must be two arguments.')
        end
        if checkCompatibility(varargin{2})
            retval = ['Histogram of ' varargin{1} '.'];
        else
            retval = ['The ' varargin{1} ' cannot be displayed with a histogram.'];
        end
    case 'checkCompatibility'
        if nargin < 2
            error('GMA:internal:GMAVisualizationHistogram:nargin2', 'There must be two arguments.')
        end
        retval = checkCompatibility(varargin{1});
    case 'display'
        if nargin ~= 5
            error('GMA:internal:GMAVisualizationHistogram:nargin5', 'There must be five arguments.')
        end
        GMAVisualizationHistogram_display(varargin{1}, varargin{2}, varargin{3}, varargin{4});
    otherwise
        error('GMA:internal:GMAVisualizationHistogram:unrecognizedFcn', 'The function was unrecognized.')
end

    function cRetVal = checkCompatibility(varStruct)
        cRetVal = false;
        if ~varStruct.singleValue
            cRetVal = true;
        end
    end
    function GMAVisualizationHistogram_display(dataObj, displayName, selectedTimestep, props)
        % Somehow, it is not possible to call functions from the
        % GMAFunctions package. Therefore, all variables necessary must be
        % passed.
        if (length(dataObj.times) > 1) && isemtpy(selectedTimestep)
            % If there is more than one timestep, then ask which timestep
            % to do a histogram on.
            error('GMA:info:GMAVisualizationHistogram:singleTimetep', 'singleTimestep')
        end
        % Check to see if the variable has the right properties.
        % Get the display name of the variable.
        if ~checkCompatibility(props)
            error('GMA:error:incompatible', 'incompatible')
        end
        % Assume that the variable exists.
        if length(dataObj.times) > 1
            timeIndex = find(strcmp(dataObj.times, selectedTimestep));
        else
            timeIndex = 1;
        end
        data = dataObj.timesteps{timeIndex}.getVariable(displayName);
        if isempty(data)
            error('GMA:error:GMAVisualizationHistogram:varNotFound', ...
                ['The variable ' displayName ' was not found.'])
        end
        % Take the data from the third dimension (realizations) and make it
        % into one long realization.
        data = reshape(data, [], 1);
        minX = min(data);
        maxX = max(data);
        % Test to see if it is discrete data or not, and apply a bin width
        % accordingly.
        intdata = int8(data);
        if intdata == data
            binWidth = 1;
        else
            binWidth = (maxX - minX) / floor(sqrt(dataObj.numParticles));
        end
        clear('intdata')
        x = minX:binWidth:maxX;
        histogramData = histc(data, x);
        % This turns it into a percentage.
        histogramData = histogramData ./ dataObj.numParticles * 100;
        clear('data')
        axesHandle = newplot;
        bar(x, histogramData', 1, 'FaceColor', [.9 .5 0], 'EdgeColor', 'none')
        ylabel(axesHandle, 'Percent Frequency')
        xlabel(axesHandle, displayName)
        title(axesHandle, ['Plot of ' displayName '.'])
    end % function GMAVisualizationHistogram_calculate
end % function GMAVisualizationHistogram


