function addCoordinates(handles)
% Adds coordinates to the data object.
% This is a callback from the load files screen when the load files screen
% is called from runIt.

dataObj = GMAFunctions.get(handles, 'dataObj');

fileList = cellstr(get(handles.filelist, 'String'));
if isempty(fileList)
    errordlg('There must be at least one file with coordinates.')
    return
end
try
    dataObj2 = GMAData(fileList);
catch err
    [level, message] = GMAFunctions.errorInfo(err);
    if isempty(level)
        % It was not a GMA error.
        errordlg(['Internal Error: ' message])
        GMAFunctions.close(handles, 'force')
        delete(handles.figure)
        rethrow(err)
    end
    if strcmp(level, 'internal')
        errordlg(['Internal Error: ' message])
        GMAFunctions.close(handles, 'force')
        delete(handles.figure)
        rethrow(err)
    elseif strcmp(level, 'fatal')
        errordlg(message)
        GMAFunctions.close(handles, 'force')
        delete(handles.figure)
        rethrow(err)
    else
        errordlg(message, 'GMA Error')
        return
    end
end

% Now transfer the coordinates from dataObj2 to dataObj
if dataObj.times ~= dataObj2.times
    errordlg(['There must be the same number of time steps in the ' ...
        'coordinates as in the loaded data.'], 'GMA Error')
    return
end
if dataObj.numParticles ~= dataObj2.numParticles
    errordlg(['There must be the same number of particles in the ' ...
        'coordinates as in the loaded data.'], 'GMA Error')
    return
end
if dataObj.numRealizations ~= dataObj2.numRealizations
    errordlg(['There must be the same number of realizations in the ' ...
        'coordinates as in the loaded data.'], 'GMA Error')
    return
end

for n = 1:length(dataObj.timesteps)
    dataObj.timesteps{n}.coordinates = dataObj2.timesteps{n}.coordinates;
end

GMAFunctions.set(handles, 'dataObj', dataObj)
GMAFunctions.set(handles, 'analysisType', 'new')

GMAFunctions.runIt(handles)

end % function addCoordinates

