function depChain = loadVar(handles, varName, depChain, waitHandle)
% Loads the selected variable then calls the visualization.
% This is what calls the calculations, if necessary.
% depChain is the list of variables called as dependencies. Used when
% checking for circular dependencies.

if nargin < 3; error('GMA:internal:loadVar:nargin', 'There must be 4 arguments.'); end

dataObj = GMAFunctions.get(handles, 'dataObj');

extensionHandles = GMAFunctions.get(handles, 'extensionHandles');
extHandle = extensionHandles.(varName);

varDisplay = extHandle('getVariableName');

if any(strcmp(varDisplay, dataObj.variablesSet))
    return
end

if nargin < 3 || isempty(depChain)
    depChain = {varName};
else
    depChain{end+1} = varName;
end

% First, load all of the dependencies.
deps = extHandle('getDependencies');
if ~isempty(deps)
    for n = 1:length(deps)
        if ~isfield(extensionHandles, deps{n})
            close(waitHandle)
            error('GMA:fatal:loadVar:invalidDependency', ['The dependency ' ...
                deps{n} ' of ' varName ' is not found.'])
        end
        if any(strcmp(deps{n}, depChain))
            close(waitHandle)
            error('GMA:fatal:loadVar:circularDependency', ['The variable ' ...
                extHandle('getVariableName') ' depends on one of its dependants, ' ...
                'though not necessarily a direct dependant.'])
        end
        extDepHandle = extensionHandles.(deps{n});
        varDepDisplay = extDepHandle('getVariableName');
        if ~any(strcmp(varDepDisplay, dataObj.variablesSet))
            depChain = GMAFunctions.loadVar(handles, deps{n}, depChain, waitHandle);
        else
            depChain{end+1} = deps{n}; %#ok<AGROW>
        end
    end
end

% Now to actually load the variable.
% Let errors propagate up to runIt.
extHandle('calculate', dataObj, waitHandle)

end % function loadVar

