function runIt(handles)
% Runs the variables and the visualization. This is the callback for many
% buttons.

% Get the selected variable.
varName = GMAFunctions.get(handles, 'selectedVariable');
% The data object is useful in any case.
dataObj = GMAFunctions.get(handles, 'dataObj');

GMAFunctions.breadcrumbs(handles, 'reset');

% Load the variable. This does calculations if necessary.
waitHandle = waitbar(0, 'Preparing...', 'WindowStyle', 'modal');
try
    GMAFunctions.loadVar(handles, varName, {}, waitHandle);
catch err
    close(waitHandle)
    handleError(err)
    return
end

close(waitHandle);



% Now run the visualization
vizName = GMAFunctions.get(handles, 'selectedVisualization');
extensionHandles = GMAFunctions.get(handles, 'extensionHandles');
varHandle = extensionHandles.(varName);
displayName = varHandle('getVariableName');
props = varHandle('getProperties');
vizHandle = extensionHandles.(vizName);
selectedTimestamp = GMAFunctions.get(handles, 'selectedTimestep');
try
    vizHandle('display', dataObj, displayName, selectedTimestamp, props);
catch err
    handleError(err)
    return
end

GMAFunctions.screenManager(handles, 'switch', 'main');

GMAFunctions.set(handles, 'selectedTimestep', {});


    function handleError(err)
        [level, message] = GMAFunctions.errorInfo(err);
        if strcmp(level, 'info')
            if strcmp(message, 'coordinates')
                % At this point, the choice of input files is set. If the
                % user wants to use different input files, then the user
                % should stop and start anew.
                GMAFunctions.set(handles, 'inputFiles', {})
                GMAFunctions.screenManager(handles, 'switch', 'loadFiles')
                handles = guihandles(handles.figure);
                set(handles.nextbutton, 'Callback',  @(h,e)GMAFunctions.addCoordinates(guihandles(h)))
                set(handles.instructions, 'String', ['Coordinates are needed to ' ...
                    'calculate ' varName '. Add the coordinate files to the list' ...
                    'below and press "Next."'])
            elseif strcmp(message, 'radius')
                GMAFunctions.screenManager(handles, 'switch', 'radius')
            elseif strcmp(message, 'boundaries')
                GMAFunctions.screenManager(handles, 'switch', 'boundaries')
            elseif strcmp(message, 'singleTimestep')
                GMAFunctions.screenManager(handles, 'switch', 'timestep')
                set(handles.instructions, 'String', 'Select a timestep to visualize.')
                set(handles.timelist, 'String', dataObj.times)
            elseif strcmp(message, 'incompatible')
                GMAFunctinos.screenManager(handles, 'switch', 'main')
                errormsg([vizName ' cannot be used on ' varName], 'GMA Error')
            else
                errormsg('Internal Error: unrecognized info error in runIt.', 'GMA Internal Error')
            end
        elseif strcmp(level, 'internal')
            errordlg(['Internal Error: ' message])
            GMAFunctions.close(handles, 'force');
            delete(handles.figure);
            rethrow(err);
        elseif strcmp(level, 'fatal')
            errordlg(message)
            GMAFunctions.close(handles, 'force');
            delete(handles.figure);
            rethrow(err);
        else
            errordlg(message, 'GMA Error')
            rethrow(err);
        end
    end % function handleError

end % function runIt

