function scr_boundaries(handles, command)
% Screen for setting the boundaries.

par = handles.Container;
dataObj = GMAFunctions.get(handles, 'dataObj');

switch command
    case 'create'
        uicontrol(par, 'Tag', 'instructions', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'Enter the locations of the walls on the system.', 'FontSize', 10)
        uicontrol(par, 'Tag', 'xperiodic', 'Style', 'checkbox', 'Units', ...
            'pixels', 'String', 'Periodic in X-direction', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_boundaries(guihandles(h),'xCheckCallback'))
        uicontrol(par, 'Tag', 'xlowerdesc', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'Lower X', 'FontSize', 10)
        uicontrol(par, 'Tag', 'xlower', 'Style', 'edit', 'Units', 'pixels', 'FontSize', 10, ...
            'String', dataObj.defaultBoundaries.lowerx, 'BackgroundColor', 'white')
        uicontrol(par, 'Tag', 'xupperdesc', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'Upper X', 'FontSize', 10)
        uicontrol(par, 'Tag', 'xupper', 'Style', 'edit', 'Units', 'pixels', 'FontSize', 10, ...
            'String', dataObj.defaultBoundaries.upperx, 'BackgroundColor', 'white')
        uicontrol(par, 'Tag', 'yperiodic', 'Style', 'checkbox', 'Units', ...
            'pixels', 'String', 'Periodic in Y-direction', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_boundaries(guihandles(h),'yCheckCallback'))
        uicontrol(par, 'Tag', 'ylowerdesc', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'Lower Y', 'FontSize', 10)
        uicontrol(par, 'Tag', 'ylower', 'Style', 'edit', 'Units', 'pixels', 'FontSize', 10, ...
            'String', dataObj.defaultBoundaries.lowery, 'BackgroundColor', 'white')
        uicontrol(par, 'Tag', 'yupperdesc', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'Upper Y', 'FontSize', 10)
        uicontrol(par, 'Tag', 'yupper', 'Style', 'edit', 'Units', 'pixels', 'FontSize', 10, ...
            'String', dataObj.defaultBoundaries.uppery, 'BackgroundColor', 'white')
        uicontrol(par, 'Tag', 'zperiodic', 'Style', 'checkbox', 'Units', ...
            'pixels', 'String', 'Periodic in Z-direction', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_boundaries(guihandles(h),'zCheckCallback'))
        uicontrol(par, 'Tag', 'zlowerdesc', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'Lower Z', 'FontSize', 10)
        uicontrol(par, 'Tag', 'zlower', 'Style', 'edit', 'Units', 'pixels', 'FontSize', 10, ...
            'String', dataObj.defaultBoundaries.lowerz, 'BackgroundColor', 'white')
        uicontrol(par, 'Tag', 'zupperdesc', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'Upper Z', 'FontSize', 10)
        uicontrol(par, 'Tag', 'zupper', 'Style', 'edit', 'Units', 'pixels', 'FontSize', 10, ...
            'String', dataObj.defaultBoundaries.upperz, 'BackgroundColor', 'white')
        uicontrol(par, 'Tag', 'nextbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Next', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_boundaries(guihandles(h),'nextCallback'))
        handles = guihandles(par);
        checkCallback('x')
        checkCallback('y')
        checkCallback('z')
        setPosition()
    case 'resize'
        setPosition()
    case 'xCheckCallback'
        checkCallback('x')
    case 'yCheckCallback'
        checkCallback('y')
    case 'zCheckCallback'
        checkCallback('z')
    case 'nextCallback'
        periodicX = get(handles.xperiodic, 'Value');
        periodicY = get(handles.yperiodic, 'Value');
        periodicZ = get(handles.zperiodic, 'Value');
        if periodicX
            xupper = real(str2double(get(handles.xupper, 'String')));
            if isnan(xupper); errordlg('The upper X boundary must be a real number.'); end
            xlower = real(str2double(get(handles.xlower, 'String')));
            if isnan(xlower); errordlg('The lower X boundary must be a real number.'); end
            if xlower > xupper
                warndlg('The lower X boundary is higher than the upper X boundary.')
                return
            elseif xlower == xupper
                warndlg('The upper and lower X boundaries appear to be the same. Are the X boundaries really periodic?')
                return
            end
        else
            xlower = 0;
            xupper = 0;
        end
        if periodicY
            yupper = real(str2double(get(handles.yupper, 'String')));
            if isnan(yupper); errordlg('The upper Y boundary must be a real number.'); end
            ylower = real(str2double(get(handles.ylower, 'String')));
            if isnan(ylower); errordlg('The lower Y boundary must be a real number.'); end
            if ylower > yupper
                warndlg('The lower Y boundary is higher than the upper X boundary.')
                return
            elseif ylower == yupper
                warndlg('The upper and lower Y boundaries appear to be the same. Are the Y boundaries really periodic?')
                return
            end
        else
            ylower = 0;
            yupper = 0;
        end
        if periodicZ
            zupper = real(str2double(get(handles.zupper, 'String')));
            if isnan(zupper); errordlg('The upper Z boundary must be a real number.'); end
            zlower = real(str2double(get(handles.zlower, 'String')));
            if isnan(zlower); errordlg('The lower Z boundary must be a real number.'); end
            if zlower > zupper
                warndlg('The lower Z boundary is higher than the upper Z boundary.')
                return
            elseif zlower == zupper
                warndlg('The upper and lower Z boundaries appear to be the same. Are the Z boundaries really periodic?')
                return
            end
        else
            zlower = 0;
            zupper = 0;
        end
        
        b = GMABoundary;
        b.set('x', [xlower xupper])
        b.set('y', [ylower yupper])
        b.set('z', [zlower zupper])
        b.setPeriodic('x', periodicX)
        b.setPeriodic('y', periodicY)
        b.setPeriodic('z', periodicZ)
        
        dataObj.setBoundaries(b)
        GMAFunctions.runIt(handles)
    otherwise
        error('GMA:internal:scr_radius:invalidCommand', 'The command given was not recognized.')
end

    function checkCallback(d)
        periodic = get(handles.([d 'periodic']), 'Value');
        if periodic
            set(handles.([d 'lower']), 'Enable', 'on')
            set(handles.([d 'upper']), 'Enable', 'on')
        else
            set(handles.([d 'lower']), 'Enable', 'off')
            set(handles.([d 'upper']), 'Enable', 'off')
        end
    end % function checkCallback

    function setPosition()
        % Get the figure size
        figsize = get(handles.figure, 'Position');
        fWidth = figsize(3);
        fHeight = figsize(4);
        row1 = fHeight - 85;
        row2 = fHeight - 120;
        row3 = fHeight - 155;
        row4 = fHeight - 190;
        row5 = fHeight - 225;
        row6 = fHeight - 260;
        textWidth = 71;
        inputWidth = fWidth / 2 - 2 * (10 + textWidth + 10 + 9);
        col1 = 10;
        col2 = 10 + textWidth + 10;
        col3 = fWidth / 2 + 10;
        col4 = fWidth / 2 + 10 + textWidth + 10;
        set(handles.instructions, 'Position', [10, fHeight-50, fWidth-19, 40])
        set(handles.xperiodic, 'Position', [col1, row1, fWidth-19, 25])
        set(handles.xlowerdesc, 'Position', [col1, row2, textWidth, 25])
        set(handles.xlower, 'Position', [col2, row2, inputWidth, 25])
        set(handles.xupperdesc, 'Position', [col3, row2, textWidth, 25])
        set(handles.xupper, 'Position', [col4, row2, inputWidth, 26])
        set(handles.yperiodic, 'Position', [col1, row3, fWidth-19, 25])
        set(handles.ylowerdesc, 'Position', [col1, row4, textWidth, 25])
        set(handles.ylower, 'Position', [col2, row4, inputWidth, 25])
        set(handles.yupperdesc, 'Position', [col3, row4, textWidth, 25])
        set(handles.yupper, 'Position', [col4, row4, inputWidth, 26])
        set(handles.zperiodic, 'Position', [col1, row5, fWidth-19, 25])
        set(handles.zlowerdesc, 'Position', [col1, row6, textWidth, 25])
        set(handles.zlower, 'Position', [col2, row6, inputWidth, 25])
        set(handles.zupperdesc, 'Position', [col3, row6, textWidth, 25])
        set(handles.zupper, 'Position', [col4, row6, inputWidth, 26])
        set(handles.nextbutton, 'Position', [fWidth-109, 10, 100, 25])
    end % function setPosition

end % function scr_boundaries

