function scr_home(handles, command)

par = handles.Container;

if nargin ~= 2; error('GMA:internal:scr_home:nargin', 'There must be 2 arguments.'); end

if strcmp(command, 'create')
    createUI()
    setPosition()
elseif strcmp(command, 'resize')
    setPosition()
elseif strcmp(command, 'newCallback')
    if ~GMAFunctions.close(handles); return; end
    GMAFunctions.set(handles, 'analysisType', 'new')
    GMAFunctions.set(handles, 'analysisOpen', true)
    GMAFunctions.screenManager(handles, 'switch', 'loadFiles')
elseif strcmp(command, 'loadCallback')
    if ~GMAFunctions.close(handles); return; end
    GMAFunctions.set(handles, 'analysisType', 'load')
    GMAFunctions.set(handles, 'analysisOpen', true)
    GMAFunctions.screenManager(handles, 'switch', 'loadSingleFile')
elseif strcmp(command, 'helpCallback')
    if exist('help.html', 'file')
        % This opens a web browser window within MATLAB.
        web([pwd filesep 'help.html'])
    else
        error('GMA:error:scr_home:missingHelp', 'The help file is missing.')
    end
else
    error('GMA:fatal:scr_home:unrecognizedCommand', 'Internal Error: unrecognized command.')
end

    function createUI()
        uicontrol(par, 'Tag', 'titletext', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'Granular Microstructure Analyzer', 'FontUnits', 'pixels', ...
            'FontWeight', 'bold')
        uicontrol(par, 'Tag', 'explaintext', 'Style', 'text', 'Units', 'pixels', ...
            'String', {['Granular Microstructure Analyzer (GMA) is a program to ', ...
            'analyze the microstructure of granular systems. GMA can calculate "variables," ', ...
            'such as the Voronoi volume and the coordination number. GMA can also ', ...
            'set up a "visualization" of a variable, such as a histogram.'], ...
            '', ...
            ['The main input to GMA is the coordinates of each particle. GMA can ', ...
            'only deal with monodisperse systems. GMA can also export the current ', ...
            'session to a "save file," allowing further visualizations to be generated ', ...
            'later without recalculating the variables.'], ...
            '', ...
            'Version 1.0', ...
            '', ...
            ['Copyright ' char(169) ' 2009-2011 Granular Science Lab, NJIT'], ...
            'All rights reserved.', ...
            '', ...
            'Coded by Nathaniel Ching, with help from', ...
            '    Dr. Anthony Rosato, Tai Anh Duong, and Vishagan Ratnaswamy'}, ...
            'HorizontalAlignment', 'left', 'FontSize', 10)
        uicontrol(par, 'Tag', 'questtext', 'Style', 'text', 'Units', 'pixels', ...
            'String', ['To begin, press "New Calculations" to load coordinate ' ...
            'files, or "Load Save File" to load a save file.'], 'FontSize', 10)
        uicontrol(par, 'Tag', 'newbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'New Calculations from Coordinates', 'Callback', ...
            @(h,e)GMAFunctions.scr_home(guihandles(h),'newCallback'), 'FontSize', 10)
        uicontrol(par, 'Tag', 'lookbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Load Save File', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_home(guihandles(h),'loadCallback'))
        uicontrol(par, 'Tag', 'helpbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Help', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_home(guihandles(h),'helpCallback'))
        % reload the handles
        handles = guihandles(par);
    end % function createUI
    function setPosition()
        % Get the figure size
        figsize = get(handles.figure, 'Position');
        fWidth = figsize(3);
        fHeight = figsize(4);
        titleFontSize = (fWidth - 19) / 20;
        set(handles.titletext, 'FontSize', titleFontSize)
        set(handles.titletext, 'Position', [10, fHeight-titleFontSize*1.2-15, fWidth-19, titleFontSize*1.2])
        set(handles.explaintext, 'Position', [10, 185, fWidth-19, fHeight-titleFontSize*1.2-210])
        set(handles.questtext, 'Position', [10, 130, fWidth-19, 40])
        set(handles.newbutton, 'Position', [fWidth/2-150, 110, 301, 25])
        set(handles.lookbutton, 'Position', [fWidth/2-150, 65, 301, 25])
        set(handles.helpbutton, 'Position', [fWidth/2-150, 20, 301, 25])
    end % function setPosition
end % function scr_home
