function scr_loadFiles(handles, command)

par = handles.Container;

if nargin ~= 2; error('GMA:internal:scr_loadfiles:nargin', 'There must be 2 arguments.'); end

switch command
    case 'create'
        createUI()
        setPosition()
    case 'resize'
        setPosition()
    case 'addFilesCallback'
        addFiles()
    case 'removeFilesCallback'
        removeFiles()
    case 'backCallback'
        GMAFunctions.screenManager(handles, 'back')
    case 'nextCallback'
        nextFcn()
    otherwise
        error('GMA:fatal:scr_loadFiles:unrecognizedCommand', 'Internal Error: unrecognized command.')
end

    function createUI()
        uicontrol(par, 'Tag', 'instructions', 'Style', 'text', 'Units', 'pixels', 'FontSize', 10, ...
            'String', ['Add files using the "Add Files" button below. Remove files ' ...
            'by selecting them and pressing "Remove Files." When finished, press "Next."'])
        uicontrol(par, 'Tag', 'addbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Add Files', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_loadFiles(guihandles(h),'addFilesCallback'))
        uicontrol(par, 'Tag', 'removebutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Remove Files', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_loadFiles(guihandles(h),'removeFilesCallback'))
        uicontrol(par, 'Tag', 'filelist', 'Style', 'listbox', 'Units', ...
            'pixels', 'Max', 3, 'String', GMAFunctions.get(handles, 'inputFiles'), ...
            'BackgroundColor', 'white', 'FontSize', 10)
        uicontrol(par, 'Tag', 'backbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Back', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_loadFiles(guihandles(h),'backCallback'))
        uicontrol(par, 'Tag', 'nextbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Next', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_loadFiles(guihandles(h),'nextCallback'))
        % reload the handles
        handles = guihandles(par);
    end % function createUI
    function setPosition()
        % Get the figure size
        figsize = get(handles.figure, 'Position');
        fWidth = figsize(3);
        fHeight = figsize(4);
        set(handles.instructions, 'Position', [10, fHeight-40, fWidth-19, 30])
        set(handles.addbutton, 'Position', [10, fHeight-75, 100, 25])
        set(handles.removebutton, 'Position', [fWidth-109, fHeight-75, 100, 25])
        set(handles.filelist, 'Position', [10, 45, fWidth-19, fHeight-130])
        set(handles.backbutton, 'Position', [10, 10, 100, 25])
        set(handles.nextbutton, 'Position', [fWidth-109, 10, 100, 25])
    end % function setPosition
    function addFiles()
        lastFolder = GMAFunctions.get(handles, 'lastOpenFolder');
        [fileName pathName] = uigetfile({'*.txt', 'Text Files (*.txt)'; '*', 'All Files'}, ...
            'Choose Files', lastFolder, 'MultiSelect', 'on');
        % If uigetfile returns numeric zero, then the user pressed
        % "Cancel."
        if isnumeric(fileName) && 0 == fileName
            return
        end
        % If the file is in the current directory, then just use the file
        % name. Otherwise, use the full path.
        if strcmp(pathName, [pwd filesep])
            fileNameList = cellstr(fileName);
        else
            fileNameList = cellstr(strcat({pathName}, fileName));
        end
        % Get the files currently on the list.
        currentFiles = cellstr(get(handles.filelist, 'String'));
        if isempty(currentFiles)
            % If there are no current files, then just use the new files.
            newFileNameList = fileNameList;
        else
            newFileNameList = unique([currentFiles, fileNameList]');
        end
        % Set the new list of files.
        set(handles.filelist, 'String', newFileNameList)
        GMAFunctions.set(handles, 'inputFiles', newFileNameList)
        GMAFunctions.set(handles, 'lastOpenFolder', [pathName filesep])
    end % function addFiles
    function removeFiles()
        % Indices are the indices of the files that are to be deleted.
        indices = get(handles.filelist, 'Value');
        % Make it so that nothing is selected in the files box.
        set(handles.filelist, 'Value', [])
        % FileList is a cell array.
        fileList = cellstr(get(handles.filelist, 'String'));
        if (length(indices) == length(fileList)) || isempty(fileList)
            fileList = {};
        else
            % FIXME: am I really coming back here after calculations?
            % If there are old files, they cannot be removed.
            oldFiles = GMAFunctions.get(handles, 'CalculatedFiles');
            if isempty(oldFiles)
                fileList(indices) = [];
            else
                % keep track of how many files are removed.
                removedFiles = 0;
                for n = 1:length(indices)
                    % Check whether the file is on the list.
                    if ~sum(strcmp(fileList(indices(n) - removedFiles), oldFiles))
                        fileList(indices(n) - removedFiles) = [];
                        removedFiles = removedFiles + 1;
                    end
                end
                if removedfiles < length(indices)
                    warndlg(['One or more of the selected files have been calculated ' ...
                        'already. If you want to start over, then choose "Close analysis" ' ...
                        'from the "File" menu in the upper left corner of the window.'], ...
                        'Warning', 'modal')
                end
            end
        end
        % Set the new files list.
        set(handles.filelist, 'String', fileList)
        GMAFunctions.set(handles, 'inputFiles', fileList)
    end % function removeFiles
    function nextFcn()
        fileList = cellstr(get(handles.filelist, 'String'));
        if isempty(fileList)
            errordlg('There must be at least one file to analyze.')
            return
        end
        try
            dataObj = GMAData(fileList);
        catch err
            [level, message] = GMAFunctions.errorInfo(err);
            if isempty(level)
                % It was not a GMA error.
                errordlg(['Internal Error: ' message])
                GMAFunctions.close(handles, 'force');
                delete(handles.figure);
                rethrow(err);
            end
            if strcmp(level, 'internal')
                errordlg(['Internal Error: ' message])
                GMAFunctions.close(handles, 'force');
                delete(handles.figure);
                rethrow(err);
            elseif strcmp(level, 'fatal')
                errordlg(message)
                GMAFunctions.close(handles, 'force');
                delete(handles.figure);
                rethrow(err);
            else
                errordlg(message, 'GMA Error')
                return
            end
        end
        GMAFunctions.set(handles, 'dataObj', dataObj)
        GMAFunctions.set(handles, 'inputFiles', fileList)
        GMAFunctions.set(handles, 'analysisOpen', true)
        GMAFunctions.screenManager(handles, 'switch', 'main')
    end % function nextFcn
end % function scr_loadFiles

