function scr_loadSingleFile(handles, command)

par = handles.Container;

if nargin ~= 2; error('GMA:internal:scr_loadSingleFile:nargin', 'There must be 2 arguments.'); end

switch command
    case 'create'
        uicontrol(par, 'Tag', 'instructions', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'Select the file created by pressing "Save All."', 'FontSize', 10)
        str = GMAFunctions.get(handles, 'inputFiles');
        if ~iscell(str) || length(str) ~= 1, str = {''}; end
        uicontrol(par, 'Tag', 'fileedit', 'Style', 'edit', 'Units', 'pixels', ...
            'String', str{1}, 'FontSize', 10, ...
            'BackgroundColor', 'white', 'HorizontalAlignment', 'left')
        uicontrol(par, 'Tag', 'browsebutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Browse...', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_loadSingleFile(guihandles(h),'browseCallback'))
        uicontrol(par, 'Tag', 'nextbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Next', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_loadSingleFile(guihandles(h),'nextCallback'))
        uicontrol(par, 'Tag', 'backbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Back', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_loadSingleFile(guihandles(h),'backCallback'))
        % reload the handles
        handles = guihandles(par);
        setPosition();
    case 'resize'
        setPosition();
    case 'browseCallback'
        [filename pathname] = uigetfile({'*.mat', 'MAT Files (*.mat)'; '*', 'All Files'}, ...
            'Choose Files', 'MultiSelect', 'off');
        % If uigetfile returns numeric zero, then the user pressed
        % "Cancel."
        if isnumeric(filename) && 0 == filename
            return
        end
        % If the file is in the current directory, then just use the file
        % name. Otherwise, use the full path.
        if ~strcmp(pathname, [pwd filesep])
            filename = [pathname filesep filename];
        end
        set(handles.fileedit, 'String', filename)
    case 'nextCallback'
        filename = get(handles.fileedit, 'String');
        if isempty(filename)
            errordlg('Please enter the file with the saved information.', 'GMA Error')
            return
        end
        fileList = {filename};
        try
            dataObj = GMAData(fileList);
        catch err
            [level, message] = GMAFunctions.errorInfo(err);
            if isempty(level)
                % It was not a GMA error.
                errordlg(['Internal Error: ' message]);
                GMAFunctions.close(handles, 'force');
                delete(handles.figure);
                rethrow(err);
            end
            if strcmp(level, 'internal')
                errordlg(['Internal Error: ' message]);
                GMAFunctions.close(handles, 'force');
                delete(handles.figure);
                rethrow(err);
            elseif strcmp(level, 'fatal')
                errordlg(message);
                GMAFunctions.close(handles, 'force');
                delete(handles.figure);
                rethrow(err);
            else
                errordlg(message, 'GMA Error');
                return
            end
        end
        analysisType = GMAFunctions.get(handles, 'analysisType');
        if strcmp(analysisType, 'load') && isempty(dataObj.variablesSet)
            warndlg(['There were no variables found in the loaded data. ' ...
                'New calculations will be done on the data.'], 'GMA Warning');
            GMAFunctions.set(handles, 'analysisType', 'new')
        end
        GMAFunctions.set(handles, 'dataObj', dataObj)
        GMAFunctions.set(handles, 'inputFiles', fileList)
        GMAFunctions.set(handles, 'analysisOpen', true)
        GMAFunctions.screenManager(handles, 'switch', 'main')
    case 'backCallback'
        GMAFunctions.screenManager(handles, 'back');
    otherwise
        error('GMA:fatal:scr_loadSingleFile:unrecognizedCommand', 'Internal Error: unrecognized command.')
end

    function setPosition()
        % Get the figure size
        figsize = get(handles.figure, 'Position');
        fWidth = figsize(3);
        fHeight = figsize(4);
        set(handles.instructions, 'Position', [10, fHeight-50, fWidth-19, 40])
        set(handles.fileedit, 'Position', [10, fHeight/2-13, fWidth-99, 25])
        set(handles.browsebutton, 'Position', [fWidth-80, fHeight/2-13, 69, 25])
        set(handles.nextbutton, 'Position', [fWidth-109, 10, 100, 25])
        set(handles.backbutton, 'Position', [10, 10, 100, 25])
    end % function setPosition

end % fuction scr_loadSingleFile

