function scr_radius(handles, command)
% Screen for setting the radius.

par = handles.Container;
dataObj = GMAFunctions.get(handles, 'dataObj');

switch command
    case 'create'
        uicontrol(par, 'Tag', 'instructions', 'Style', 'text', 'Units', 'pixels', ...
            'String', 'What is the radius of a single particle?', 'FontSize', 10)
        uicontrol(par, 'Tag', 'inputbox', 'Style', 'edit', 'Units', 'pixels', 'FontSize', 10, ...
            'String', num2str(dataObj.defaultRadius), 'BackgroundColor', 'white')
        uicontrol(par, 'Tag', 'nextbutton', 'Style', 'pushbutton', 'Units', ...
            'pixels', 'String', 'Next', 'FontSize', 10, 'Callback', ...
            @(h,e)GMAFunctions.scr_radius(guihandles(h),'nextCallback'))
        handles = guihandles(par);
        setPosition()
    case 'resize'
        setPosition()
    case 'nextCallback'
        radius = get(handles.inputbox, 'String');
        if isempty(radius)
            errordlg('Input a radius.')
            return
        end
        radius = str2double(radius);
        if isnan(radius)
            errordlg('The radius given was not recognized as a number.')
            return
        end
        if ~isreal(radius) || radius <= 0
            errordlg('The radius must be a real, positive number.')
            return
        end
        dataObj.setRadius(radius)
        GMAFunctions.runIt(handles)
    otherwise
        error('GMA:internal:scr_radius:invalidCommand', 'The command given was not recognized.')
end

    function setPosition()
        % Get the figure size
        figsize = get(handles.figure, 'Position');
        fWidth = figsize(3);
        fHeight = figsize(4);
        set(handles.instructions, 'Position', [10, fHeight-50, fWidth-19, 40])
        set(handles.inputbox, 'Position', [fWidth/2-25, fHeight/2-13, 50, 25])
        set(handles.nextbutton, 'Position', [fWidth-109, 10, 100, 25])
    end % function setPosition

end % function scr_radius

