classdef GMABoundary < handle
    properties (Constant)
        version = 1.0;
    end % properties (Constant)
    properties (SetAccess = protected)
        upperx = 0;
        lowerx = 0;
        periodicx = false;
        uppery = 0;
        lowery = 0;
        periodicy = false;
        upperz = 0;
        lowerz = 0;
        periodicz = false;
        isSet = false;
    end % properties (SetAccess = protected)
    methods
        function retVal = getX(obj)
            obj.sort();
            retVal = struct('upper', obj.upperx, 'lower', obj.lowerx);
        end
        function retVal = getY(obj)
            obj.sort();
            retVal = struct('upper', obj.uppery, 'lower', obj.lowery);
        end
        function retVal = getZ(obj)
            obj.sort();
            retVal = struct('upper', obj.upperz, 'lower', obj.lowerz);
        end
        function retVal = getUpper(obj)
            obj.sort();
            retVal = struct('x', obj.upperx, 'y', obj.uppery, 'z', obj.upperz);
        end
        function retVal = getLower(obj)
            obj.sort();
            retVal = struct('x', obj.lowerx, 'y', obj.lowery, 'z', obj.lowerz);
        end
        function retVal = getPeriodic(obj, dir)
            obj.sort();
            if nargin > 1 && ~isempty(dir) && any(strcmp(dir, {'x','y','z'}))
                retVal = obj.(['periodic' dir]);
            else
                retVal = struct('x', obj.periodicx, 'y', obj.periodicy, 'z', obj.periodicz);
            end
        end
        function sort(obj)
            for dim = {'x', 'y', 'z'}
                if obj.(['upper' dim]) < obj.(['lower' dim])
                    [obj.(['upper' dim]), obj.(['lower' dim])] ...
                        = GMABoundaries.swapValues(obj.(['upper' dim]), obj.(['lower' dim]));
                end
            end
        end % function sort
        function set(obj, dir, val)
            if ~any(strcmp({'x','y','z'}, dir))
                error('GMA:internal:GMABoundary:set:direction', ...
                    'The direction in GMABoundary:set must be x, y, or z.')
            end
            % val must be a two element array.
            if length(val) ~= 2
                error('GMA:internal:GMABoundary:set:value', ...
                    'The value must be a two element array.')
            end
            obj.(['upper' dir]) = max(val);
            obj.(['lower' dir]) = min(val);
            obj.isSet = true;
        end
        function setPeriodic(obj, dir, val)
            if ~any(strcmp({'x','y','z'}, dir))
                error('GMA:internal:GMABoundary:setPeriodic:direction', ...
                    'The direction in GMABoundary:setPeriodic must be x, y, or z.')
            end
            if val
                obj.(['periodic' dir]) = true;
            else
                obj.(['periodic' dir]) = false;
            end
        end
    end % methods
end

